#include "predef.h" 
#include <ctype.h>
#include <basictypes.h>
#include <sim5282.h>
#include <pins.h>

void InitA2D()
{
    J2[25].function(PINJ2_25_SPI_CLK);
    J2[27].function(PINJ2_27_SPI_DIN);
    J2[28].function(PINJ2_28_SPI_DOUT);
    J2[30].function(PINJ2_30_SPI_CS0);
    J2[26].function(PINJ2_26_SPI_CS3);
    sim.qspi.qmr = 0x8020;     // 1000 0000 0010 0000
    sim.qspi.qdlyr = 0x0010;   // 0000 0000 0000 1000  Delay 256 33MHz clocks
    sim.qspi.qwr = 0x1100;     // 0001 0000 0000 0000 
    sim.qspi.qar = 0x0;
    sim.qspi.qdr = 0xAA00;     // 1010 0010 0110 0000  Write A2D command reg
    sim.qspi.qdr = 0xAA00;     // 1010 0010 0110 0000  Write A2D command reg
       // Int Ref., 4V, Long Samples, Int. Conv. Clk, single shot          
    sim.qspi.qar = 0x20;
    sim.qspi.qdr = 0x6E00;     // 0110 1110 0000 0000 CS0
    sim.qspi.qdr = 0x6700;     // 0110 0111 0000 0000 CS3
    sim.qspi.qir |= 1;
    sim.qspi.qdlyr |= 0x8000;  // Send config register write
    while(( sim.qspi.qir & 1 ) == 0);
    
    // Now control reg. is configured and we need to start the reading
    sim.qspi.qar = 0x20;
    for(int i = 0; i < 7; i++)
      sim.qspi.qdr = 0x6E00;     // 0110 1110 0000 0000 CS0
    for(int i = 0; i < 8; i++)
      sim.qspi.qdr = 0x6700;     // 0110 0111 0000 0000 CS3
    
    sim.qspi.qdr = 0x6E00;     // 0110 1110 0000 0000 CS0
      
    sim.qspi.qar = 0x0;
    sim.qspi.qdr = 0x1000;    // Read Channel 1
    sim.qspi.qdr = 0x2000;    // Read Channel 2
    sim.qspi.qdr = 0x3000;    // Read Channel 3
    sim.qspi.qdr = 0x4000;    // Read Channel 4
    sim.qspi.qdr = 0x5000;    // Read Channel 5
    sim.qspi.qdr = 0x6000;    // Read Channel 6
    sim.qspi.qdr = 0x7000;    // Read Channel 7
    sim.qspi.qdr = 0x0000;    // Read Channel 0
    sim.qspi.qdr = 0x1000;    // Read Channel 1
    sim.qspi.qdr = 0x2000;    // Read Channel 2
    sim.qspi.qdr = 0x3000;    // Read Channel 3
    sim.qspi.qdr = 0x4000;    // Read Channel 4
    sim.qspi.qdr = 0x5000;    // Read Channel 5
    sim.qspi.qdr = 0x6000;    // Read Channel 6
    sim.qspi.qdr = 0x7000;    // Read Channel 7
    sim.qspi.qdr = 0x0000;    // Read Channel 0
    
    sim.qspi.qwr = 0x5F00;     // 0101 1111 0000 0000 
    sim.qspi.qmr = 0x8020;     // 1000 0000 0010 0000
    
    sim.qspi.qir |= 1;
    sim.qspi.qdlyr |= 0x8000;  // Send config register write    
}

WORD ReadA2DChannel( int channel )
{
   sim.qspi.qir |= 1;
   sim.qspi.qwr |= 0x8000;
   while(( sim.qspi.qir & 1 ) == 0);
   sim.qspi.qar = (0x10 +  channel);
   WORD ret = sim.qspi.qdr;
   sim.qspi.qwr &= ~0x8000;
   sim.qspi.qir |= 1;
   sim.qspi.qdlyr |= 0x8000;  // Send config register write    
   return (ret >> 4);
}

void ReadA2DAll( WORD* buffer )
{
   sim.qspi.qir |= 1;
   sim.qspi.qwr |= 0x8000;
   while(( sim.qspi.qir & 1 ) == 0);
   sim.qspi.qar = 0x10;
   for(int i = 0; i < 16; i++)
      *buffer++ = (sim.qspi.qdr >> 4);
   sim.qspi.qwr &= ~0x8000;
   sim.qspi.qir |= 1;
   sim.qspi.qdlyr |= 0x8000;  // Send config register write    
   return;
}

void Test5000()
{
   sim.qspi.qir |= 1;
   sim.qspi.qwr |= 0x8000;
   while(( sim.qspi.qir & 1 ) == 0);
   sim.qspi.qwr = 0x1F00;     // 0001 1111 0000 0000 
   sim.qspi.qir |= 1;
   sim.qspi.qdlyr |= 0x8000;  // Send config register write  
   while(( sim.qspi.qir & 1 ) == 0);
   
   for(int i = 0; i<5000; i++)
   {
      while(( sim.qspi.qir & 1 ) == 0);
      sim.qspi.qir |= 1;
      sim.qspi.qdlyr |= 0x8000;  // Send config register write  
   }
      
   while(( sim.qspi.qir & 1 ) == 0);
   sim.qspi.qwr = 0x5F00;     // 0101 1111 0000 0000 
   sim.qspi.qir |= 1;
   sim.qspi.qdlyr |= 0x8000;  // Send config register write  
}
   
       
